// Copyright 2018 The ksonnet authors
//
//
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.

package serial

// Action is an action that can be run serially.
type Action func() error

// RunActions runs a set of actions serially. If an error occurs,
// it is returned and processing stops.
func RunActions(actions ...Action) error {
	for _, a := range actions {
		err := a()
		if err != nil {
			return err
		}
	}

	return nil
}
